@@ -151,11 +151,16 @@ namespaces."""
         if '.' not in name:
             return self._namespace.get(name)
         else:
-            (ns, name) = name.split('.', 1)
+            (ns, giname) = name.split('.', 1)
             if ns == self._namespace.name:
-                return self._namespace.get(name)
+                return self._namespace.get(giname)
+            # Fallback to the main namespace if not a dependency and matches a prefix
+            if ns in self._namespace.identifier_prefixes and not ns in self._includes:
+                message.warn(("Deprecated reference to identifier " +
+                              "prefix %s in GIName %s") % (ns, name))
+                return self._namespace.get(giname)
             include = self._includes[ns]
-            return include.get(name)
+            return include.get(giname)
 
     def lookup_typenode(self, typeobj):
         """Given a Type object, if it points to a giname,
@@ -705,6 +710,9 @@ raise ValueError."""
         return ast.Return(typeval)
 
     def _create_const(self, symbol):
+        if symbol.ident.startswith('_'):
+            return None
+
         # Don't create constants for non-public things
         # http://bugzilla.gnome.org/show_bug.cgi?id=572790
         if (symbol.source_filename is None or
