@@ -3323,6 +3323,20 @@ regress_test_callback_destroy_notify (RegressTestCallbackUserData callback,
   return retval;
 }
 
+/**
+ * regress_test_callback_destroy_notify_no_user_data:
+ * @callback: (scope notified):
+ *
+ * Adds a scope notified callback with no user data. This can invoke an error
+ * condition in bindings which needs to be tested.
+ **/
+int
+regress_test_callback_destroy_notify_no_user_data (RegressTestCallbackUserData callback,
+                              GDestroyNotify notify)
+{
+  return regress_test_callback_destroy_notify(callback, NULL, notify);
+}
+
 /**
  * regress_test_callback_thaw_notifications:
  *
@@ -3500,6 +3514,18 @@ regress_test_owned_gerror_callback (RegressTestCallbackOwnedGError callback)
   callback (error);
 }
 
+/**
+ * regress_test_skip_unannotated_callback: (skip)
+ * @callback: No annotation here
+ *
+ * Should not emit a warning:
+ * https://bugzilla.gnome.org/show_bug.cgi?id=685399
+ */
+void
+regress_test_skip_unannotated_callback (RegressTestCallback callback)
+{
+}
+
 /* interface */
 
 static void
