@@ -150,6 +150,13 @@ GVariant *regress_test_gvariant_as (void);
 
 #define NUM_REGRESS_FOO
 
+/**
+ * RegressTestEnum:
+ * @REGRESS_TEST_VALUE1: value 1
+ * @REGRESS_TEST_VALUE2: value 2
+ *
+ * By purpose, not all members have documentation
+ */
 typedef enum
 {
   REGRESS_TEST_VALUE1,
@@ -697,6 +704,8 @@ void regress_test_gerror_callback (RegressTestCallbackGError callback);
 void regress_test_null_gerror_callback (RegressTestCallbackGError callback);
 void regress_test_owned_gerror_callback (RegressTestCallbackOwnedGError callback);
 
+void regress_test_skip_unannotated_callback (RegressTestCallback callback);
+
 typedef struct _RegressTestInterface RegressTestInterface;
 
 /* interface */
@@ -889,7 +898,6 @@ void regress_test_struct_fixed_array_frob (RegressTestStructFixedArray *str);
 void regress_has_parameter_named_attrs (int        foo,
                                         gpointer   attributes);
 
-
 typedef struct {
   int dummy;
   struct {
@@ -900,6 +908,11 @@ typedef struct {
   double dummy2;
 } RegressLikeGnomeKeyringPasswordSchema;
 
+/* Ensure we ignore symbols that start with _; in particular we don't
+ * want to issue a namespace warning.
+ */
+#define _DONTSCANTHIS 1
+
 /* https://bugzilla.gnome.org/show_bug.cgi?id=685022 */
 #define REGRESS_MININT64 ((gint64) G_GINT64_CONSTANT(0x8000000000000000))
 #define REGRESS_MAXUINT64 (G_GINT64_CONSTANT(0xffffffffffffffffU))
